@@ -1,14 +1,14 @@
 import unittest
 
-from tests.tests_caching_table.table_models import InoftVocalEngineUsersCachingTable
-from tests.tests_query_operations.table_models import InoftVocalEngineTableModel
+from tests.components.playground_table_clients import PlaygroundInoftVocalEngineCachingTable
+from tests.tests_caching_table.table_models import InoftVocalEngineTableModel
 
 
-class TestInoftVocalEngineCachingTable(unittest.TestCase):
+class TestsInoftVocalEngineCachingTable(unittest.TestCase):
     def __init__(self, method_name: str):
         super().__init__(methodName=method_name)
-        # self.users_table = InoftVocalEngineUsersBasicTable(data_model=InoftVocalEngineTableModel)
-        self.users_table = InoftVocalEngineUsersCachingTable(data_model=InoftVocalEngineTableModel)
+        # self.users_table = PlaygroundInoftVocalEngineBasicTable(data_model=InoftVocalEngineTableModel)  # todo: implement the InoftVocalEngineBasicTable
+        self.users_table = PlaygroundInoftVocalEngineCachingTable(data_model=InoftVocalEngineTableModel)
         self.users_table.debug = True
 
         self.SHARED_CASE_KWARGS = {'self': self, 'users_table': self.users_table, 'primary_key_name': 'accountProjectUserId', 'is_caching': True}
